@@ -1,12 +1,12 @@
 package Time::Duration::Parse::AsHash;
 
 our $DATE = '2016-05-17'; # DATE
-our $VERSION = '0.10.4'; # VERSION
+our $VERSION = '0.10.5'; # VERSION
 
 #IFUNBUILT
-use strict;
-use warnings;
-#IFUNBUILT
+# # use strict;
+# # use warnings;
+#END IFUNBUILT
 
 use Exporter;
 our @ISA    = qw( Exporter );
@@ -100,7 +100,7 @@ Time::Duration::Parse::AsHash - Parse string that represents time duration
 
 =head1 VERSION
 
-version 0.10.4
+version 0.10.5
 
 =head1 SYNOPSIS
 
@@ -143,7 +143,7 @@ C<decades>. This will be returned in C<years> key.
 =item * It has a lower startup overhead
 
 By avoiding modules like L<Carp> and L<Exporter::Lite>, even L<strict> and
-L<warnings>.
+L<warnings> (starts up in ~3m vs ~9ms on my computer).
 
 =back
 
